[dovecot-cvs] dovecot/src/lib-storage mail-sort.c,1.2,1.3 mail-storage.h,1.21,1.22

cras at procontrol.fi cras at procontrol.fi
Fri Dec 6 03:09:25 EET 2002


Update of /home/cvs/dovecot/src/lib-storage
In directory danu:/tmp/cvs-serv6082/lib-storage

Modified Files:
	mail-sort.c mail-storage.h 
Log Message:
Renamed IBuffer and OBuffer to IStream and OStream which describes their
functionality better. I tried to keep the variable names and comments also
sensible.



Index: mail-sort.c
===================================================================
RCS file: /home/cvs/dovecot/src/lib-storage/mail-sort.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- mail-sort.c	5 Dec 2002 22:37:33 -0000	1.2
+++ mail-sort.c	6 Dec 2002 01:09:23 -0000	1.3
@@ -1,7 +1,7 @@
 /* Copyright (C) 2002 Timo Sirainen */
 
 #include "lib.h"
-#include "obuffer.h"
+#include "ostream.h"
 #include "mail-sort.h"
 
 #include <stdlib.h>

Index: mail-storage.h
===================================================================
RCS file: /home/cvs/dovecot/src/lib-storage/mail-storage.h,v
retrieving revision 1.21
retrieving revision 1.22
diff -u -d -r1.21 -r1.22
--- mail-storage.h	4 Dec 2002 18:28:37 -0000	1.21
+++ mail-storage.h	6 Dec 2002 01:09:23 -0000	1.22
@@ -152,24 +152,24 @@
 	int (*copy)(Mailbox *box, Mailbox *destbox,
 		    const char *messageset, int uidset);
 
 	/* Fetch wanted mail data. The results are written into outbuf
 	   in RFC2060 FETCH format. */
 	int (*fetch)(Mailbox *box, MailFetchData *fetch_data,
-		     OBuffer *outbuf, int *all_found);
+		     OStream *output, int *all_found);
 
 	/* Search wanted mail data. args contains the search criteria.
-	   Results are written into outbuf in RFC2060 SEARCH format.
+	   Results are written into output stream in RFC2060 SEARCH format.
 	   If charset is NULL, the given search strings are matched without
 	   any conversion. */
 	int (*search)(Mailbox *box, const char *charset, MailSearchArg *args,
-		      MailSortType *sorting, OBuffer *outbuf, int uid_result);
+		      MailSortType *sorting, OStream *output, int uid_result);
 
 	/* Save a new mail into mailbox. timezone_offset specifies the
 	   timezone in minutes which internal_date was originally given
 	   with. */
 	int (*save)(Mailbox *box, MailFlags flags, const char *custom_flags[],
 		    time_t internal_date, int timezone_offset,
-		    IBuffer *data, uoff_t data_size);
+		    IStream *data, uoff_t data_size);
 
 	/* Returns TRUE if mailbox is now in inconsistent state, meaning that
 	   the message IDs etc. may have changed - only way to recover this
@@ -152,24 +152,24 @@
 		    const char *messageset, int uidset);
 
-	/* Fetch wanted mail data. The results are written into outbuf
+	/* Fetch wanted mail data. The results are written into output stream
 	   in RFC2060 FETCH format. */
 	int (*fetch)(Mailbox *box, MailFetchData *fetch_data,




More information about the dovecot-cvs mailing list